<?php


/**
 * 获取自定义分类法筛选配置
 * @Author Dadong2g
 * @date   2022-12-04
 * @return [type]
 */
function get_site_custom_taxonomy() {

    $data   = _cao('site_custom_taxonomy', array());
    $config = array();
    if (empty($data) || !is_array($data)) {
        return array();
    }

    foreach ($data as $key => $value) {

        $custom_taxonomy = trim($value['taxonomy']);

        if (!preg_match("/^[a-zA-Z\s]+$/", $custom_taxonomy)) {
            continue; //不是英文标识
        }

        $config[$custom_taxonomy] = $value;
    }

    return $config;
}

/**
 * 根据分类id获取当前分类筛选配置
 * @Author Dadong2g
 * @date   2022-12-04
 * @param  [type]     $cat_id [description]
 * @return [type]
 */
function get_cat_filter_config($cat_id) {

    $data   = _cao('site_term_filter_config', array());

    if (empty($cat_id) || empty($data)) {
        return array();
    }

    $config = array();

    foreach ($data as $item) {
        if ($item['cat_id'] == $cat_id) {
            $config = $item;
        }
    }

    return $config;
}

// 自定义分类筛选
// prefix custom
//
add_action('init', function () {

    $custom_taxonomy = get_site_custom_taxonomy();

    if (empty($custom_taxonomy)) {
        return;
    }

    foreach ($custom_taxonomy as $tax_key => $tax_item) {

        if ($tax_key == 'type') {
            continue;
        }
        
        if (taxonomy_exists($tax_key)) {
            continue;
        }

        register_extended_taxonomy($tax_key, 'post', [
            'labels'       => [
                'name'          => $tax_item['name'],
                'singular_name' => $tax_item['name'],
                'menu_name'     => $tax_item['name'],
                'search_items'  => __('搜索', 'ripro'),
                'all_items'     => __('全部', 'ripro'),
                'view_item'     => __('查看', 'ripro'),
                'edit_item'     => __('编辑', 'ripro'),
                'update_item'   => __('更新', 'ripro'),
                'add_new_item'  => __('添加新', 'ripro') . $tax_item['name'],
                'new_item_name' => __('新增', 'ripro'),
            ],
            'hierarchical' => false,
            'meta_box'     => $tax_item['type'],
            'rewrite'      => [
                'slug' => $tax_key,
            ],
        ]);
    }

});






//自定义文章
add_action('init', function () {
    
    // 自定义商品文章类型 form stores
    if (is_site_cdk_shop()): 
    register_extended_post_type('cdk', [

        'labels'        => [
            'name'                  => __('发卡商店', 'ripro'),
            'singular_name'         => __('发卡', 'ripro'),
            'menu_name'             => __('发卡', 'ripro'),
            'name_admin_bar'        => __('发卡商品', 'ripro'),
            'add_new'               => __('新增发卡', 'ripro'),
            'add_new_item'          => __('新增发卡', 'ripro'),
            'new_item'              => __('新发卡', 'ripro'),
            'edit_item'             => __('编辑发卡', 'ripro'),
            'view_item'             => __('查看发卡', 'ripro'),
            'all_items'             => __('全部发卡', 'ripro'),
            'search_items'          => __('搜索发卡', 'ripro'),
            'not_found'             => __('未找到发卡.', 'ripro'),
            'not_found_in_trash'    => __('未找到发卡.', 'ripro'),
            'archives'              => __('发卡存档', 'ripro'),
            'insert_into_item'      => __('插入发卡', 'ripro'),
            'uploaded_to_this_item' => __('上传到此发卡', 'ripro'),
            'filter_items_list'     => __('筛选发卡列表', 'ripro'),
            'items_list_navigation' => __('发卡列表导航', 'ripro'),
            'items_list'            => __('发卡列表', 'ripro'),
        ],

        'menu_icon'     => 'dashicons-cart',
        'show_in_feed'  => false,
        'show_in_rest'  => true,
        'block_editor'  => false,
        'supports'      => array('title', 'editor','thumbnail'),

        # Show all posts on the post type archive:
        'archive'       => [
            'nopaging' => true,
        ],
        'rewrite'       => [
            'permastruct' => '/cdk/%postname%.html',
        ],

        # Add some custom columns to the admin screen:
        'admin_cols'    => [
            
            // 'featured_image' => [
            //     'title'          => '缩略图',
            //     'featured_image' => 'thumbnail',
            // ],

            'post_id' => [
                'title'       => 'ID',
                'post_field'  => 'ID',
            ],

            'cao_price' => [
                'title'    => '售价',
                'meta_key' => 'cao_price',
            ],

            'cao_count' => [
                'title'    => '库存',
                'meta_key' => 'cao_count',
            ],


            'cdk_type'     => [
                'title'    => '发卡类型',
                'function' => function () {
                    $post_id = get_the_ID();
                    $type = get_post_meta($post_id,'cdk_type',1);
                    $type = (empty($type)) ? 'lock' : $type;
                    $types = array(
                        'lock'   => '固定发卡',
                        'read'   => '动态发卡',
                    );
                    echo $types[$type];
                },
            ],

            'pay_count'     => [
                'title'    => '销量',
                'function' => function () {
                    $post_id = get_the_ID();
                    echo '0';
                },
            ],

            'post_date' => [
                'title'       => '发布日期',
                'post_field'  => 'post_date',
                'date_format' => 'Y-m-d H:i',

            ],

            'last_modified' => [
                'title'       => '最近修改',
                'post_field'  => 'post_modified',
                'date_format' => 'Y-m-d H:i',
            ],

            
        ],

        # Add some dropdown filters to the admin screen:
        'admin_filters' => [
            

        ],

    ], [

        # Override the base names used for labels:
        'singular' => 'cdk',
        'plural'   => 'cdks',
        'slug'     => 'cdks',

    ]);
    endif;



});



if (!class_exists('CSF')) {
    return;
}


// 表单字段 form forms
if (!empty(_cao('is_site_cdk_shop', 1))):

$prefix = 'cdk_Post_options';

CSF::createMetabox($prefix, array(
    'title'     => '发卡购买配置(RiPro-V5)',
    'nav'       => 'inline',
    'post_type' => array('cdk'),
    'data_type' => 'unserialize', //unserialize serialize
    'context'   => 'normal', //`normal`, `side`, `advanced`
));

CSF::createSection($prefix, array(
    'title'  => '价格设置',
    'fields' => array(

        array(
            'id'          => 'cao_price',
            'type'        => 'number',
            'title'       => '价格：*',
            'desc'        => '必填，不允许为0',
            'unit'        => esc_html(_cao('site_coin_name','金币')),
            'output'      => '.heading',
            'output_mode' => 'width',
            'default'     => '1',
        ),
        array(
            'id'          => 'cao_count',
            'type'        => 'number',
            'title'       => '库存数量：*',
            'desc'        => '必填',
            'unit'        => '个',
            'output'      => '.heading',
            'output_mode' => 'width',
            'default'     => 9999,
        ),

    ),
));

CSF::createSection($prefix, array(
    'title'  => '发卡配置',
    'fields' => array(

        array(
            'id'      => 'cdk_type',
            'type'    => 'radio',
            'title'   => '发卡类型',
            'inline'  => true,
            'options' => array(
                'lock'   => '固定发卡',
                'read'   => '动态发卡',
            ),
            'desc'    => '',
            'default' => 'lock',
        ),
        
        array(
            'id'         => 'cdk_data',
            'type'       => 'textarea',
            'title'      => '发卡数据',
            'desc'       => '固定发卡模式：填写一个发卡信息即可，动态模式：每行一个发货信息，发一个减一个，用户购买后自动发货',
        ),

    ),
));

endif;
